@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <lttoolbox/compiler.h>
@@ -33,7 +31,8 @@
 
 using namespace std;
 
-Expander::Expander()
+Expander::Expander() :
+reader(0)
 {
   LtLocale::tryToSetLocale();
 }
@@ -385,8 +384,8 @@ Expander::procEntry(FILE *output)
       // deteccin del uso de paradigmas no definidos
 
       if(paradigm.find(p) == paradigm.end() &&
-         paradigm_lr.find(p) == paradigm.end() &&
-         paradigm_rl.find(p) == paradigm.end())
+         paradigm_lr.find(p) == paradigm_lr.end() &&
+         paradigm_rl.find(p) == paradigm_rl.end())
       {
         wcerr << L"Error (" << xmlTextReaderGetParserLineNumber(reader);
         wcerr << L"): Undefined paradigm '" << p << L"'." <<endl;
