@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 #include <lttoolbox/fst_processor.h>
 #include <lttoolbox/lttoolbox_config.h>
@@ -50,7 +48,7 @@ void endProgram(char *name)
   cout << "  -e, --decompose-nouns:  Try to decompound unknown words" << endl;
   cout << "  -g, --generation:       morphological generation" << endl;
   cout << "  -l, --tagged-gen:       morphological generation keeping lexical forms" << endl;
-  cout << "  -m, --tagged-nm-gen:    same as -l but without unknown word marks" << endl;                              
+  cout << "  -m, --tagged-nm-gen:    same as -l but without unknown word marks" << endl;
   cout << "  -n, --non-marked-gen    morph. generation without unknown word marks" << endl;
   cout << "  -o, --surf-bilingual:   lexical transfer with surface forms" << endl;
   cout << "  -p, --post-generation:  post-generation" << endl;
@@ -114,7 +112,7 @@ int main(int argc, char *argv[])
       {"case-sensitive",  0, 0, 'c'},
       {"help",            0, 0, 'h'}
     };
-#endif    
+#endif
 
   while(true)
   {
@@ -123,20 +121,20 @@ int main(int argc, char *argv[])
     int c = getopt_long(argc, argv, "abceglmndopstzwvh", long_options, &option_index);
 #else
     int c = getopt(argc, argv, "abceglmndopstzwvh");
-#endif    
+#endif
 
     if(c == -1)
     {
       break;
     }
-      
+
     switch(c)
     {
     case 'c':
       fstp.setCaseSensitiveMode(true);
       break;
 
-    case 'e':      
+    case 'e':
     case 'a':
     case 'b':
     case 'o':
@@ -179,7 +177,7 @@ int main(int argc, char *argv[])
 
   FILE *input = stdin, *output = stdout;
   LtLocale::tryToSetLocale();
-  
+
   if(optind == (argc - 3))
   {
     FILE *in = fopen(argv[optind], "rb");
@@ -188,21 +186,21 @@ int main(int argc, char *argv[])
       cerr << "Error: Cannot not open file '" << argv[optind] << "'." << endl << endl;
       exit(EXIT_FAILURE);
     }
-    
+
     input = fopen(argv[optind+1], "rb");
     if(input == NULL || ferror(input))
     {
       cerr << "Error: Cannot not open file '" << argv[optind+1] << "'." << endl << endl;
       exit(EXIT_FAILURE);
     }
-    
+
     output= fopen(argv[optind+2], "wb");
     if(output == NULL || ferror(output))
     {
       cerr << "Error: Cannot not open file '" << argv[optind+2] << "'." << endl << endl;
       exit(EXIT_FAILURE);
     }
-    
+
     fstp.load(in);
     fclose(in);
   }
@@ -214,17 +212,17 @@ int main(int argc, char *argv[])
       cerr << "Error: Cannot not open file '" << argv[optind] << "'." << endl << endl;
       exit(EXIT_FAILURE);
     }
-    
+
     input = fopen(argv[optind+1], "rb");
     if(input == NULL || ferror(input))
     {
       cerr << "Error: Cannot not open file '" << argv[optind+1] << "'." << endl << endl;
       exit(EXIT_FAILURE);
     }
-    
+
     fstp.load(in);
     fclose(in);
-  }   
+  }
   else if(optind == (argc - 1))
   {
     FILE *in = fopen(argv[optind], "rb");
@@ -233,7 +231,7 @@ int main(int argc, char *argv[])
       cerr << "Error: Cannot not open file '" << argv[optind] << "'." << endl << endl;
       exit(EXIT_FAILURE);
      }
-    fstp.load(in);    
+    fstp.load(in);
     fclose(in);
   }
   else
@@ -261,13 +259,13 @@ int main(int argc, char *argv[])
         checkValidity(fstp);
         fstp.generation(input, output);
         break;
-      
+
       case 'd':
         fstp.initGeneration();
         checkValidity(fstp);
         fstp.generation(input, output, gm_all);
         break;
-      
+
       case 'l':
         fstp.initGeneration();
         checkValidity(fstp);
@@ -279,7 +277,7 @@ int main(int argc, char *argv[])
         checkValidity(fstp);
         fstp.generation(input, output, gm_tagged_nm);
         break;
-      
+
       case 'p':
         fstp.initPostgeneration();
         checkValidity(fstp);
@@ -293,18 +291,18 @@ int main(int argc, char *argv[])
         break;
 
       case 't':
-        fstp.initPostgeneration(); 
+        fstp.initPostgeneration();
         checkValidity(fstp);
         fstp.transliteration(input, output);
         break;
-        
+
       case 'o':
         fstp.initBiltrans();
         checkValidity(fstp);
         fstp.setBiltransSurfaceForms(true);
         fstp.bilingual(input, output);
         break;
-   
+
       case 'b':
         fstp.initBiltrans();
         checkValidity(fstp);
@@ -316,10 +314,10 @@ int main(int argc, char *argv[])
         checkValidity(fstp);
         fstp.analysis(input, output);
         break;
-      
+
       case 'a':
       default:
-        fstp.initAnalysis(); 
+        fstp.initAnalysis();
         checkValidity(fstp);
         fstp.analysis(input, output);
         break;
@@ -329,13 +327,13 @@ int main(int argc, char *argv[])
   {
     cerr << e.what();
     if (fstp.getNullFlush()) {
-      fputws_unlocked('\0', output);
+      fputwc_unlocked(L'\0', output);
     }
 
     exit(1);
   }
 
   fclose(input);
-  fclose(output); 
+  fclose(output);
   return EXIT_SUCCESS;
 }
